smartcard.Exceptions.InvalidATRMaskLengthException

# ``smartcard`.`Exceptions`.`InvalidATRMaskLengthException``

exception documentation

`class InvalidATRMaskLengthException(SmartcardException):`

View In Hierarchy

Raised when an ATR mask does not match an ATR length.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, mask):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented